# Contributing to tweedledum

First off, thanks for taking the time to contribute!

**Note**: by contributing code to the **tweedledum** project in any form, 
including sending a pull request via Github, a code fragment or patch via
private email, you agree to release your code under the terms of the MIT license
that you can find in the LICENSE file included in the **tweedledum** source
distribution.  You will include following header within each source file that
you contribute.

```c++
/*------------------------------------------------------------------------------
| Part of Tweedledum Project.  This file is distributed under the MIT License.
| See accompanying file /LICENSE for details.
*-----------------------------------------------------------------------------*/
```
## I just have a question!!!

Then just send me an e-mail at <bruno [dot] schmitt [at] epfl [dot] ch>.

> **Note:** Please don't file an issue to ask a question. Github issues 
**SHOULD ONLY BE USED** to report bugs, and for **DETAILED** feature requests.

## How to provide a patch for a new feature

1. If it is a major feature or a semantical change, please send me an e-mail at 
<bruno [dot] schmitt [at] epfl [dot] ch>. In this first step **please don't
write code yet**.

2. If in step 1 you get an acknowledgment, use the following procedure to submit a patch:
    * Fork **tweedledum** on github (http://help.github.com/fork-a-repo/)
    * Create a topic branch (git checkout -b my_branch)
    * Push to your branch (git push origin my_branch)
    * Initiate a pull request on github (https://help.github.com/articles/creating-a-pull-request/)
    * Done :)

For minor fixes just open a pull request on Github.